@@ -11,11 +11,12 @@ class GlobalErrorBoundary extends React.Component {
     super(props)
 
     this.reloadMsg = (locale) => {
-      this.setState(({ msgContextState }) => ({ msgContextState: {
-        msg: createMessages(locale),
-        locale,
-        reloadMsg: msgContextState.reloadMsg,
-      },
+      this.setState(({ msgContextState }) => ({
+        msgContextState: {
+          msg: createMessages(locale),
+          locale,
+          reloadMsg: msgContextState.reloadMsg,
+        },
       }))
     }
 
