@@ -1,7 +1,6 @@
 import {
   ADD_NETWORKS_TO_VNIC_PROFILES,
   SET_VNIC_PROFILES,
-  GET_ALL_VNIC_PROFILES,
 } from '_/constants'
 
 export function setVnicProfiles ({ vnicProfiles }) {
@@ -13,10 +12,6 @@ export function setVnicProfiles ({ vnicProfiles }) {
   }
 }
 
-export function getAllVnicProfiles () {
-  return { type: GET_ALL_VNIC_PROFILES }
-}
-
 export function addNetworksToVnicProfiles ({ networks }) {
   return {
     type: ADD_NETWORKS_TO_VNIC_PROFILES,
