@@ -117,9 +117,9 @@ function getInitialState ({
     const operatingSystem = operatingSystems.find(os => os.get('name') === osName)
     const operatingSystemId = operatingSystem.get('id')
     const memoryInB = blankTemplate.get('memory')
-    const cpus = blankTemplate.getIn([ 'cpu', 'vCPUs' ])
-    const initEnabled = blankTemplate.getIn([ 'cloudInit', 'enabled' ])
-    const topology = blankTemplate.getIn([ 'cpu', 'topology' ]).toJS()
+    const cpus = blankTemplate.getIn(['cpu', 'vCPUs'])
+    const initEnabled = blankTemplate.getIn(['cloudInit', 'enabled'])
+    const topology = blankTemplate.getIn(['cpu', 'topology']).toJS()
 
     blankTemplateValues = {
       operatingSystemId,
@@ -275,22 +275,24 @@ class CreateVmWizard extends React.Component {
             : this.props.userMessages
               .get('records')
               .filter(
-                record => record.getIn([ 'failedAction', 'meta', 'correlationId' ]) === correlationId
+                record => record.getIn(['failedAction', 'meta', 'correlationId']) === correlationId
               )
               .map(record => buildMessageFromRecord(record.toJS(), msg))
               .toJS()
 
-          return <SummaryReview
-            id='create-vm-wizard-review'
-            basic={this.state.steps.basic}
-            network={this.state.steps.network.nics}
-            storage={this.state.steps.storage.disks}
-            progress={{
-              inProgress,
-              result: correlatedResult, // undefined (no result yet) | 'success' | 'error'
-              messages: correlatedMessages,
-            }}
-          />
+          return (
+            <SummaryReview
+              id='create-vm-wizard-review'
+              basic={this.state.steps.basic}
+              network={this.state.steps.network.nics}
+              storage={this.state.steps.storage.disks}
+              progress={{
+                inProgress,
+                result: correlatedResult, // undefined (no result yet) | 'success' | 'error'
+                messages: correlatedMessages,
+              }}
+            />
+          )
         },
         onExit: () => {
           this.setState(produce(draft => { draft.correlationId = null }))
@@ -401,8 +403,10 @@ class CreateVmWizard extends React.Component {
                    *   - server or high performance -> Clone -> raw / as defined in the template
                    */
                   const diskType = // constrain to values from createDiskTypeList()
-                    template.get('type') === 'desktop' ? 'thin'
-                      : this.state.steps.basic.optimizedFor === 'desktop' ? 'thin'
+                    template.get('type') === 'desktop'
+                      ? 'thin'
+                      : this.state.steps.basic.optimizedFor === 'desktop'
+                        ? 'thin'
                         : disk.get('sparse') ? 'thin' : 'pre'
 
                   return {
@@ -535,63 +539,69 @@ class CreateVmWizard extends React.Component {
     const enableGoBack = activeStepIndex > 0 && !isPrimaryClose && this.wizardAllowClickBack()
     const enableGoForward = (isReviewStep && !vmCreateWorking) || this.wizardAllowClickNext()
 
-    return <React.Fragment>
-      {!showCloseWizardDialog && <Wizard
-        dialogClassName='modal-lg wizard-pf'
-        show={this.props.show}
-      >
-        <Wizard.Header onClose={this.showCloseWizardDialog} title={msg.addNewVm()} />
-        <Wizard.Body>
-          <Wizard.Pattern.Body
-            steps={this.wizardSteps}
-            activeStepIndex={activeStepIndex}
-            activeStepStr={(activeStepIndex + 1).toString()}
-            goToStep={this.wizardGoToStep}
-          />
-        </Wizard.Body>
-        <Wizard.Footer>
-          <Button bsStyle='default' onClick={this.showCloseWizardDialog}>
-            { msg.createVmWizardButtonCancel() }
-          </Button>
-          <Button
-            bsStyle='default'
-            onClick={this.wizardClickBack}
-            disabled={!enableGoBack}
+    return (
+      <>
+        {!showCloseWizardDialog && (
+          <Wizard
+            dialogClassName='modal-lg wizard-pf'
+            show={this.props.show}
           >
-            <Icon type='fa' name='angle-left' />
-            { msg.createVmWizardButtonBack() }
-          </Button>
-          { isPrimaryClose &&
-          <Button onClick={this.hideAndResetState}>
-            { msg.createVmWizardButtonClose() }
-          </Button>
-          }
-          <Button
-            bsStyle='primary'
-            onClick={
-              isPrimaryNext ? this.wizardClickNext
-                : isPrimaryCreate ? this.handleCreateVm
-                  : this.hideAndNavigate
-            }
-            disabled={!enableGoForward}
-          >
-            { isPrimaryNext && msg.createVmWizardButtonNext() }
-            { isPrimaryCreate && msg.createVmWizardButtonCreate() }
-            { isPrimaryClose && msg.createVmWizardButtonCloseAndNavigate() }
-            <Icon type='fa' name='angle-right' />
-          </Button>
-        </Wizard.Footer>
-      </Wizard>
+            <Wizard.Header onClose={this.showCloseWizardDialog} title={msg.addNewVm()} />
+            <Wizard.Body>
+              <Wizard.Pattern.Body
+                steps={this.wizardSteps}
+                activeStepIndex={activeStepIndex}
+                activeStepStr={(activeStepIndex + 1).toString()}
+                goToStep={this.wizardGoToStep}
+              />
+            </Wizard.Body>
+            <Wizard.Footer>
+              <Button bsStyle='default' onClick={this.showCloseWizardDialog}>
+                { msg.createVmWizardButtonCancel() }
+              </Button>
+              <Button
+                bsStyle='default'
+                onClick={this.wizardClickBack}
+                disabled={!enableGoBack}
+              >
+                <Icon type='fa' name='angle-left' />
+                { msg.createVmWizardButtonBack() }
+              </Button>
+              { isPrimaryClose && (
+                <Button onClick={this.hideAndResetState}>
+                  { msg.createVmWizardButtonClose() }
+                </Button>
+              )}
+              <Button
+                bsStyle='primary'
+                onClick={
+                  isPrimaryNext
+                    ? this.wizardClickNext
+                    : isPrimaryCreate
+                      ? this.handleCreateVm
+                      : this.hideAndNavigate
+                }
+                disabled={!enableGoForward}
+              >
+                { isPrimaryNext && msg.createVmWizardButtonNext() }
+                { isPrimaryCreate && msg.createVmWizardButtonCreate() }
+                { isPrimaryClose && msg.createVmWizardButtonCloseAndNavigate() }
+                <Icon type='fa' name='angle-right' />
+              </Button>
+            </Wizard.Footer>
+          </Wizard>
+        )
       }
-      <NavigationConfirmationModal
-        show={showCloseWizardDialog}
-        onYes={() => {
-          this.setState(produce(draft => { draft.showCloseWizardDialog = false }))
-          this.hideAndResetState()
-        }}
-        onNo={this.hideCloseWizardDialog}
-      />
-    </React.Fragment>
+        <NavigationConfirmationModal
+          show={showCloseWizardDialog}
+          onYes={() => {
+            this.setState(produce(draft => { draft.showCloseWizardDialog = false }))
+            this.hideAndResetState()
+          }}
+          onNo={this.hideCloseWizardDialog}
+        />
+      </>
+    )
   }
 }
 
