@@ -26,9 +26,9 @@ class ScrollPositionHistory extends React.Component {
 
   render () {
     return (
-      <React.Fragment>
+      <>
         {this.props.children}
-      </React.Fragment>
+      </>
     )
   }
 }
